@@ -12,11 +12,17 @@
 #' @export
 #' @name ConstantFuture-class
 #' @keywords internal
-ConstantFuture <- function(expr=NULL, envir=emptyenv(), substitute=FALSE, globals=NULL, packages=NULL, local=FALSE, ...) {
+ConstantFuture <- function(expr = NULL, envir = emptyenv(), substitute = FALSE, globals = NULL, packages = NULL, local = FALSE, ...) {
   expr <- force(expr)
-  f <- Future(expr=expr, envir=emptyenv(), substitute=FALSE, globals=NULL, packages=NULL, local=FALSE, ...)
-  f$value <- expr
+  f <- Future(expr = expr, envir = emptyenv(), substitute = FALSE, globals = NULL, packages = NULL, local = FALSE, ...)
+  f$result <- FutureResult(value = expr)
   f$state <- "finished"
-  structure(f, class=c("ConstantFuture", class(f)))
+  structure(f, class = c("ConstantFuture", class(f)))
   f
 }
+
+
+#' @export
+result.ConstantFuture <- function(future, ...) {
+  future$result
+}
\ No newline at end of file
