@@ -82,8 +82,11 @@ run.MulticoreFuture <- function(future, ...) {
 
 #' @export
 resolved.MulticoreFuture <- function(x, timeout = 0.2, ...) {
-  ## Is future even launched?
-  if (x$state == "created") return(FALSE)
+  ## A lazy future not even launched?
+  if (x$state == "created") {
+    x <- run(x)
+    return(FALSE)
+  }
 
   ## Is value already collected?
   if (!is.null(x$result)) {
