@@ -123,19 +123,11 @@ for (type in types) {
     print(f)
     v <- value(f, signal = FALSE)
     print(v)
-    stopifnot(inherits(v, "error"))
-    ## FIXME: Related to Issue #200
-    ## https://github.com/HenrikBengtsson/Wishlist-for-R/issues/57
-    ## stopifnot(inherits(v, "MyError"))
+    stopifnot(inherits(v, "error"), inherits(v, "MyError"))
   
     ## Make sure error is signaled
     res <- tryCatch(value(f), error = identity)
-    stopifnot(inherits(res, "error"))
-  
-    ## Issue #200: Custom condition class attributes are lost 
-    ## https://github.com/HenrikBengtsson/Wishlist-for-R/issues/57
-    ## FIXME:
-    ## stopifnot(inherits(res, "MyError"))    
+    stopifnot(inherits(res, "error"), inherits(res, "MyError"))    
   
     message("*** cluster() - too large globals ...")
     ooptsT <- options(future.globals.maxSize = object.size(1:1014))
