@@ -2,26 +2,29 @@ source("incl/start,load-only.R")
 
 message("*** plan() ...")
 
-message("*** Set strategy via future::plan(future::multisession)")
-oplan <- future::plan(future::multisession)
+cl <- future::makeClusterPSOCK(1L)
+print(cl)
+
+message("*** Set strategy via future::plan(future::sequential)")
+oplan <- future::plan(future::sequential)
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
 
-message("*** Set strategy via future::plan(future::multisession, globals = FALSE)")
-oplan <- future::plan(future::multisession, globals = FALSE)
+message("*** Set strategy via future::plan(future::cluster, workers = cl, globals = FALSE)")
+oplan <- future::plan(future::cluster, workers = cl, globals = FALSE)
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
 
-message("*** Set strategy via future::plan(future::multisession(globals = FALSE)")
-oplan <- future::plan(future::multisession(globals = FALSE))
+message("*** Set strategy via future::plan(future::cluster(workers = cl, globals = FALSE)")
+oplan <- future::plan(future::cluster(workers = cl, globals = FALSE))
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
 
-message("*** Set strategy via future::plan('multisession')")
-oplan <- future::plan("multisession")
+message("*** Set strategy via future::plan('sequential')")
+oplan <- future::plan("sequential")
 print(future::plan())
 future::plan(oplan)
 print(future::plan())
@@ -57,14 +60,14 @@ stopifnot(v == 0)
 
 message("*** plan('sequential')")
 ## Setting strategy by name
-plan("multisession")
+plan("sequential")
 print(plan())
 
 
 message("*** plan() and overriding defaults")
 message("*** plan(sequential)")
 plan(sequential)
-fcn <- plan()
+fcn <- plan("next")
 print(fcn)
 stopifnot(formals(fcn)$local == TRUE)
 x <- 0
@@ -74,7 +77,7 @@ stopifnot(x == 0)
 
 message("*** plan(sequential, local = FALSE)")
 plan(sequential, local = FALSE)
-fcn <- plan()
+fcn <- plan("next")
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
 x <- 0
@@ -84,63 +87,63 @@ stopifnot(x == 1)
 
 message("*** plan(sequential, local = FALSE, abc = 1, def = TRUE)")
 plan(sequential, local = FALSE, abc = 1, def = TRUE)
-fcn <- plan()
+fcn <- plan("next")
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
 
 message("*** plan(sequential(local = FALSE))")
-plan(multisession)
+plan(cluster, workers = cl)
 plan(sequential(local = FALSE))
-fcn <- plan()
+fcn <- plan("next")
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
 
 message("*** plan(tweak(sequential, local = FALSE))")
-plan(multisession)
+plan(cluster, workers = cl)
 plan(tweak(sequential, local = FALSE))
-fcn <- plan()
+fcn <- plan("next")
 print(fcn)
 stopifnot(formals(fcn)$local == FALSE)
 
 
 message("*** old <- plan(new)")
-truth <- plan()
-old <- plan(multisession, globals = FALSE)
+truth <- plan("next")
+old <- plan(cluster, workers = cl, globals = FALSE)
 stopifnot(identical(unclass(old), unclass(truth)))
 
-curr <- plan()    ## curr == multisession(globals = FALSE)
-prev <- plan(old) ## prev == sequential(local = FALSE)
+curr <- plan("next") ## curr == cluster(workers = cl, globals = FALSE)
+prev <- plan(old)    ## prev == sequential(local = FALSE)
 stopifnot(identical(unclass(curr), unclass(prev)))
 
-curr <- plan()    ## curr == old
+curr <- plan("next") ## curr == old
 stopifnot(identical(unclass(curr), unclass(old)))
 stopifnot(identical(unclass(curr), unclass(truth)))
 
 message("*** %plan% 'sequential'")
-plan(multisession)
+plan(cluster, workers = cl)
 x %<-% { a <- 1 } %plan% "sequential"
-stopifnot(identical(body(plan()), body(multisession)))
+stopifnot(identical(body(plan("next")), body(cluster)))
 
 message("*** %plan% sequential")
-plan(multisession)
+plan(cluster, workers = cl)
 
 ## %plan% can operate on any expression, so it
 ## works just as an withPlan({ ... }, plan = ...)
-fun <- { plan() } %plan% sequential
+fun <- { plan("next") } %plan% sequential
 f <- fun(1)
 stopifnot(inherits(f, "SequentialFuture"), !f$lazy, inherits(f, "SequentialFuture"))
 
 x %<-% { a <- 1 } %plan% sequential
-stopifnot(identical(body(plan()), body(multisession)))
+stopifnot(identical(body(plan("next")), body(cluster)))
 
 message("*** %plan% sequential(local = FALSE) ")
-plan(multisession)
+plan(cluster, workers = cl)
 a <- 0
 x %<-% { a } %plan% sequential(local = FALSE)
 a <- 42
 print(x)
 stopifnot(x == 0)
-stopifnot(identical(body(plan()), body(multisession)))
+stopifnot(identical(body(plan("next")), body(cluster)))
 
 message("*** Nested futures with different plans")
 
@@ -197,6 +200,10 @@ plan(list("sequential", "sequential"))
 a %<-% { b %<-% 42; b }
 stopifnot(a == 42)
 
+plan(list("future::sequential", "sequential"))
+a %<-% { b %<-% 42; b }
+stopifnot(a == 42)
+
 message("*** plan() by functions and character names ... DONE")
 
 
@@ -217,6 +224,7 @@ print(plan())
 
 message("*** plan() w/ commands ... DONE")
 
+parallel::stopCluster(cl)
 
 message("*** plan() ... DONE")
 
