@@ -100,11 +100,16 @@ message("*** .length() ... DONE")
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 message("*** mdebug() ...")
 
-mdebug("Hello #1")
+mdebug("Hello #", 1)
+mdebugf("Hello #%d", 1)
 options(future.debug = TRUE)
-mdebug("Hello #2")
+
+mdebug("Hello #", 2)
+mdebugf("Hello #%d", 2)
 options(future.debug = FALSE)
-mdebug("Hello #3")
+
+mdebug("Hello #", 3)
+mdebugf("Hello #%d", 3)
 
 message("*** mdebug() ... DONE")
 
@@ -229,6 +234,10 @@ stopifnot(is.logical(exists), length(exists) == 1L,
 
 message("*** pid_exists() ... DONE")
 
+message("*** inRCmdCheck() ...")
+cat(sprintf("R CMD check is running: %s\n", inRCmdCheck()))
+message("*** inRCmdCheck() ... DONE")
+
 message("*** utils ... DONE")
 
 source("incl/end.R")
